@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 use base 'Net::Server::PreFork';
-our $VERSION = '2.20180525'; # VERSION
+our $VERSION = '2.20180526'; # VERSION
 
 
 use English qw{ -no_match_vars };
@@ -896,31 +896,48 @@ sub sort_callbacks {
 
     my @todo = sort @{$callbacks_ref};
     my $todo_count = scalar @todo;
+
+    # Process requirements
+    my $requirements = {};
+    foreach my $item ( @todo ) {
+        $requirements->{ $item } = [];
+        my $handler = $self->{'handler'}->{ $item };
+        my $requires_method = $callback . '_requires';
+        if ( $handler->can( $requires_method ) ) {
+            my $requires = $handler->$requires_method;
+            foreach my $require ( @{ $requires } ) {
+                push @{ $requirements->{ $item } }, $require;
+            }
+        }
+    }
+    foreach my $item ( @todo ) {
+        my $handler = $self->{'handler'}->{ $item };
+        my $requires_method = $callback . '_required_before';
+        if ( $handler->can( $requires_method ) ) {
+            my $requires = $handler->$requires_method;
+            foreach my $require ( @{ $requires } ) {
+                push @{ $requirements->{ $require } }, $item;
+            }
+        }
+    }
+
     while ( $todo_count ) {
         my @defer;
         foreach my $item ( @todo ) {
-            my $handler = $self->{'handler'}->{ $item };
-            my $requires_method = $callback . '_requires';
-            if ( $handler->can( $requires_method ) ) {
-                my $requires_met = 1;
-                my $requires = $handler->$requires_method;
-                foreach my $require ( @{ $requires } ) {
-                    if ( ! exists $added->{$require} ) {
-                        $requires_met = 0;
-                    }
-                }
-                if ( $requires_met == 1 ) {
-                    push @order, $item;
-                    $added->{$item} = 1;
-                }
-                else {
-                    push @defer, $item;
+            my $requires_met = 1;
+            my $requires = $requirements->{ $item };
+            foreach my $require ( @{ $requires } ) {
+                if ( ! exists $added->{$require} ) {
+                    $requires_met = 0;
                 }
             }
-            else {
+            if ( $requires_met == 1 ) {
                 push @order, $item;
                 $added->{$item} = 1;
             }
+            else {
+                push @defer, $item;
+            }
         }
 
         my $defer_count = scalar @defer;
@@ -1049,7 +1066,7 @@ Mail::Milter::Authentication - A Perl Mail Authentication Milter
 
 =head1 VERSION
 
-version 2.20180525
+version 2.20180526
 
 =head1 SYNOPSIS
 
