@@ -1,7 +1,7 @@
 package Mail::Milter::Authentication::Handler;
 use strict;
 use warnings;
-our $VERSION = '2.20180525'; # VERSION
+our $VERSION = '2.20180526'; # VERSION
 
 use Digest::MD5 qw{ md5_hex };
 use English qw{ -no_match_vars };
@@ -29,14 +29,6 @@ sub new {
         'thischild' => $thischild,
     };
     bless $self, $class;
-
-    my $config = $self->config();
-    if ( exists( $config->{ '_external_callback_processor' } ) ) {
-        if ( $config->{ '_external_callback_processor' }->can( 'set_handler' ) ) {
-            $config->{ '_external_callback_processor' }->set_handler( $self );
-        }
-    }
-
     return $self;
 }
 
@@ -113,13 +105,6 @@ sub top_setup_callback {
     $self->dbgout( 'CALLBACK', 'Setup', LOG_DEBUG );
     $self->set_return( $self->smfis_continue() );
 
-    my $config = $self->config();
-    if ( exists( $config->{ '_external_callback_processor' } ) ) {
-        if ( $config->{ '_external_callback_processor' }->can( 'setup_callback' ) ) {
-            $config->{ '_external_callback_processor' }->setup_callback();
-        }
-    }
-
     my $callbacks = $self->get_callbacks( 'setup' );
     foreach my $handler ( @$callbacks ) {
         $self->dbgout( 'CALLBACK', 'Setup ' . $handler, LOG_DEBUG );
@@ -212,12 +197,6 @@ sub top_connect_callback {
 
         $self->{'ip_object'} = $ip;
 
-        if ( exists( $config->{ '_external_callback_processor' } ) ) {
-            if ( $config->{ '_external_callback_processor' }->can( 'connect_callback' ) ) {
-                $config->{ '_external_callback_processor' }->connect_callback( $hostname, $ip );
-            }
-        }
-
         my $callbacks = $self->get_callbacks( 'connect' );
         foreach my $handler ( @$callbacks ) {
             $self->dbgout( 'CALLBACK', 'Connect ' . $handler, LOG_DEBUG );
@@ -294,12 +273,6 @@ sub top_helo_callback {
 
             $self->{'helo_name'} = $helo_host;
 
-            if ( exists( $config->{ '_external_callback_processor' } ) ) {
-                if ( $config->{ '_external_callback_processor' }->can( 'helo_callback' ) ) {
-                    $config->{ '_external_callback_processor' }->helo_callback( $helo_host );
-                }
-            }
-
             my $callbacks = $self->get_callbacks( 'helo' );
             foreach my $handler ( @$callbacks ) {
                 $self->dbgout( 'CALLBACK', 'Helo ' . $handler, LOG_DEBUG );
@@ -359,12 +332,6 @@ sub top_envfrom_callback {
         delete $self->{'pre_headers'};
         delete $self->{'add_headers'};
 
-        if ( exists( $config->{ '_external_callback_processor' } ) ) {
-            if ( $config->{ '_external_callback_processor' }->can( 'envfrom_callback' ) ) {
-                $config->{ '_external_callback_processor' }->envfrom_callback( $env_from );
-            }
-        }
-
         my $callbacks = $self->get_callbacks( 'envfrom' );
         foreach my $handler ( @$callbacks ) {
             $self->dbgout( 'CALLBACK', 'EnvFrom ' . $handler, LOG_DEBUG );
@@ -414,12 +381,6 @@ sub top_envrcpt_callback {
             $self->set_alarm( $config->{'command_timeout'} );
         }
 
-        if ( exists( $config->{ '_external_callback_processor' } ) ) {
-            if ( $config->{ '_external_callback_processor' }->can( 'envrcpt_callback' ) ) {
-                $config->{ '_external_callback_processor' }->envrcpt_callback( $env_to );
-            }
-        }
-
         my $callbacks = $self->get_callbacks( 'envrcpt' );
         foreach my $handler ( @$callbacks ) {
             $self->dbgout( 'CALLBACK', 'EnvRcpt ' . $handler, LOG_DEBUG );
@@ -472,12 +433,6 @@ sub top_header_callback {
             $self->dbgout( 'inline error $error', '', LOG_DEBUG );
         }
 
-        if ( exists( $config->{ '_external_callback_processor' } ) ) {
-            if ( $config->{ '_external_callback_processor' }->can( 'header_callback' ) ) {
-                $config->{ '_external_callback_processor' }->header_callback( $header, $value );
-            }
-        }
-
         my $callbacks = $self->get_callbacks( 'header' );
         foreach my $handler ( @$callbacks ) {
             $self->dbgout( 'CALLBACK', 'Header ' . $handler, LOG_DEBUG );
@@ -525,12 +480,6 @@ sub top_eoh_callback {
             $self->set_alarm( $config->{'content_timeout'} );
         }
 
-        if ( exists( $config->{ '_external_callback_processor' } ) ) {
-            if ( $config->{ '_external_callback_processor' }->can( 'eoh_callback' ) ) {
-                $config->{ '_external_callback_processor' }->eoh_callback();
-            }
-        }
-
         my $callbacks = $self->get_callbacks( 'eoh' );
         foreach my $handler ( @$callbacks ) {
             $self->dbgout( 'CALLBACK', 'EOH ' . $handler, LOG_DEBUG );
@@ -579,12 +528,6 @@ sub top_body_callback {
             $self->set_alarm( $config->{'content_timeout'} );
         }
 
-        if ( exists( $config->{ '_external_callback_processor' } ) ) {
-            if ( $config->{ '_external_callback_processor' }->can( 'body_callback' ) ) {
-                $config->{ '_external_callback_processor' }->body_callback( $body_chunk );
-            }
-        }
-
         my $callbacks = $self->get_callbacks( 'body' );
         foreach my $handler ( @$callbacks ) {
             $self->dbgout( 'CALLBACK', 'Body ' . $handler, LOG_DEBUG );
@@ -633,12 +576,6 @@ sub top_eom_callback {
             $self->set_alarm( $config->{'content_timeout'} );
         }
 
-        if ( exists( $config->{ '_external_callback_processor' } ) ) {
-            if ( $config->{ '_external_callback_processor' }->can( 'eom_callback' ) ) {
-                $config->{ '_external_callback_processor' }->eom_callback();
-            }
-        }
-
         my $callbacks = $self->get_callbacks( 'eom' );
         foreach my $handler ( @$callbacks ) {
             $self->dbgout( 'CALLBACK', 'EOM ' . $handler, LOG_DEBUG );
@@ -709,12 +646,6 @@ sub top_abort_callback {
             $self->set_alarm( $config->{'command_timeout'} );
         }
 
-        if ( exists( $config->{ '_external_callback_processor' } ) ) {
-            if ( $config->{ '_external_callback_processor' }->can( 'abort_callback' ) ) {
-                $config->{ '_external_callback_processor' }->abort_callback();
-            }
-        }
-
         my $callbacks = $self->get_callbacks( 'abort' );
         foreach my $handler ( @$callbacks ) {
             $self->dbgout( 'CALLBACK', 'Abort ' . $handler, LOG_DEBUG );
@@ -762,12 +693,6 @@ sub top_close_callback {
             $self->set_alarm( $config->{'content_timeout'} );
         }
 
-        if ( exists( $config->{ '_external_callback_processor' } ) ) {
-            if ( $config->{ '_external_callback_processor' }->can( 'close_callback' ) ) {
-                $config->{ '_external_callback_processor' }->close_callback();
-            }
-        }
-
         my $callbacks = $self->get_callbacks( 'close' );
         foreach my $handler ( @$callbacks ) {
             $self->dbgout( 'CALLBACK', 'Close ' . $handler, LOG_DEBUG );
@@ -1780,7 +1705,7 @@ Mail::Milter::Authentication::Handler
 
 =head1 VERSION
 
-version 2.20180525
+version 2.20180526
 
 =head1 DESCRIPTION
 
