@@ -1,7 +1,7 @@
 package Mail::Milter::Authentication::Metric;
 use strict;
 use warnings;
-our $VERSION = '2.20180525'; # VERSION
+our $VERSION = '2.20180526'; # VERSION
 use English qw{ -no_match_vars };
 use JSON;
 use Mail::Milter::Authentication::Config qw{ get_config };
@@ -308,6 +308,16 @@ sub child_handler {
             print $socket qq{
             </ul>
         </li>
+        <li>Registered Callbacks
+            <ul>};
+
+            foreach my $stage ( qw{ setup connect helo envfrom envrcpt header eoh body eom abort close addheader } ) {
+                my $callbacks = $server->{ 'handler' }->{ '_Handler' }->get_callbacks( $stage );
+                print $socket "<li>$stage: " . join( ', ', @$callbacks ) . "</li>";
+            }
+
+            print $socket qq{</ul>
+        </lu>
         <li>Connection Details
             <ul>};
             print $socket '<li>Protocol: ' . $config->{'protocol'} . '</li>';
@@ -358,7 +368,7 @@ Mail::Milter::Authentication::Metric
 
 =head1 VERSION
 
-version 2.20180525
+version 2.20180526
 
 =head1 DESCRIPTION
 
